---
feature_story: FS_36_17_84_44
feature_title: check script
feature_status: TODO
---

The script is supposed to provide single place to perform multi-level verification.

This script may overlap with functions from FS_85_33_46_53 `bootstrap_dev_env`.

See also FS_86_73_43_45 server control scripts.

It can start with checking:
*   Python version
*   `venv` existence
*   `argrelay` package existence

Then it jumps into checks implemented in Python (for testability) to verify:
*   whether it is run under FS_58_61_77_69 `dev_shell`
*   whether `PATH` env var reaches client and server binaries
*   whether completion is configured in shell
*   config locations used
*   any useful missing (or useless existing) settings in `~/.inputrc`
*   server availability
*   server version and compatibility
*   prints server instance id and whatever we can query to verify its state
*   print plugin list (serialized DAG) with types and activation status
*   any useful `readline` settings set or not
*   FS_57_36_37_48 (multiple clients) show all registered clients
*   show all registered commands (FS_57_36_37_48 per client)

What else?
